# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .interpreted_data import InterpretedData as InterpretedData_ed4f0d4c
    from .x_data_series import XDataSeries as XDataSeries_b8150b89
    from .data.x_data_source import XDataSource as XDataSource_f6340d57

class XDataInterpreter(XInterface_8f010a43):
    """
    offers tooling to interpret different data sources in a structural and chart-type-dependent way.

    See Also:
        `API XDataInterpreter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XDataInterpreter.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.XDataInterpreter']

    def getChartTypeSpecificData(self, sKey: str) -> object:
        """
        Get chart information that is specific to a particular chart type, by key.
        
        Supported key strings:
        """
    def interpretDataSource(self, xSource: 'XDataSource_f6340d57', aArguments: 'typing.Tuple[PropertyValue_c9610c73, ...]', aSeriesToReUse: 'typing.Tuple[XDataSeries_b8150b89, ...]') -> 'InterpretedData_ed4f0d4c':
        """
        Interprets the given data.
        
        For standard parameters that may be used, see the service StandardDiagramCreationParameters.
        """
    def isDataCompatible(self, aInterpretedData: 'InterpretedData_ed4f0d4c') -> bool:
        """
        parses the given data and states, if a reinterpretDataSeries() call can be done without data loss.
        """
    def mergeInterpretedData(self, aInterpretedData: 'InterpretedData_ed4f0d4c') -> 'XDataSource_f6340d57':
        """
        Try to reverse the operation done in interpretDataSource().
        
        In case aInterpretedData is the result of interpretDataSource()( xSource ), the result of this method should be xSource.
        """
    def reinterpretDataSeries(self, aInterpretedData: 'InterpretedData_ed4f0d4c') -> 'InterpretedData_ed4f0d4c':
        """
        Re-interprets the data given in aInterpretedData while keeping the number of data series and the categories.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .data_pilot_field_filter import DataPilotFieldFilter as DataPilotFieldFilter_271e0eed

class XDrillDownDataSupplier(XInterface_8f010a43):
    """
    supplies a filtered subset of the original data source based on filtering criteria.
    
    A service that acts as a DataPilot data source can optionally implement this interface to allow drill-down of result data. The method this interface provides is used internally when calling XDataPilotTable2.getDrillDownData() or XDataPilotTable2.insertDrillDownSheet(). If the data source service does not implement this interface, then the aforementioned two methods will have no effect.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XDrillDownDataSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XDrillDownDataSupplier.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XDrillDownDataSupplier']

    def getDrillDownData(self, aFilters: 'typing.Tuple[DataPilotFieldFilter_271e0eed, ...]') -> 'typing.Tuple[typing.Tuple[object, ...], ...]':
        """
        This method returns filtered subset of the original source data based on a given set of filtering criteria.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .layout_size import LayoutSize as LayoutSize_84cd09ff

class XSidebarPanel(ABC):
    """
    Optional interface of sidebar panels.

    See Also:
        `API XSidebarPanel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XSidebarPanel.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.XSidebarPanel']

    def getHeightForWidth(self, nWidth: int) -> 'LayoutSize_84cd09ff':
        """
        For a given width of the container the layouter asks every ui element for its optimal height.
        
        The height to which a ui element is set may differ from the returned value.
        
        The height is set via the XWindow interface.
        """
    def getMinimalWidth(self) -> int:
        """
        Minimal possible width of this panel in pixels.
        
        If this value is smaller than the maximum allowed size of the Sidebar (see config option 'org.openoffice.Office.UI.Sidebar.General.MaximumWidth'), the config option will be ignored and the new maximum Sidebar width will be getMinimalWidth() + 100px.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XLoadListener(XEventListener_c7230c4a):
    """
    receives load-related events from a loadable object.
    
    The interface is typically implemented by data-bound components, which want to listen to the data source that contains their database form.

    See Also:
        `API XLoadListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XLoadListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.XLoadListener']

    def loaded(self, aEvent: 'EventObject_a3d70b03') -> None:
        """
        is invoked when the object has successfully connected to a datasource.
        """
    def reloaded(self, aEvent: 'EventObject_a3d70b03') -> None:
        """
        is invoked when the object has been reloaded.
        """
    def reloading(self, aEvent: 'EventObject_a3d70b03') -> None:
        """
        is invoked when the object is about to be reloaded.
        
        Components may use this to stop any other event processing related to the event source until they get the reloaded event.
        """
    def unloaded(self, aEvent: 'EventObject_a3d70b03') -> None:
        """
        is invoked after the object has disconnected from a datasource.
        """
    def unloading(self, aEvent: 'EventObject_a3d70b03') -> None:
        """
        is invoked when the object is about to be unloaded.
        
        Components may use this to stop any other event processing related to the event source before the object is unloaded.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .dictionary_list_event import DictionaryListEvent as DictionaryListEvent_7cdd1129

class XDictionaryListEventListener(XEventListener_c7230c4a):
    """
    This interfaces allows the object to act according to dictionary-list events.
    
    This interface is the base class for all dictionary-list event listeners. Its single function will be called by the broadcasting dictionary-list in order to notify its registered listeners.

    See Also:
        `API XDictionaryListEventListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionaryListEventListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.linguistic2.XDictionaryListEventListener']

    def processDictionaryListEvent(self, aDicListEvent: 'DictionaryListEvent_7cdd1129') -> None:
        """
        is used to notify the object about dictionary-list events.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4


class InsertCommandArgument(object):
    """
    Struct Class

    The argument for the command \"insert\".

    See Also:
        `API InsertCommandArgument <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1InsertCommandArgument.html>`_
    """
    typeName: Literal['com.sun.star.ucb.InsertCommandArgument']

    def __init__(self, Data: typing.Optional[XInputStream_98d40ab4] = ..., ReplaceExisting: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Data (XInputStream, optional): Data value.
            ReplaceExisting (bool, optional): ReplaceExisting value.
        """


    @property
    def Data(self) -> XInputStream_98d40ab4:
        """
        A stream containing document data.
        
        This member can be left blank, if no (new) document data shall be written by the implementation of the \"insert\" command.
        """


    @property
    def ReplaceExisting(self) -> bool:
        """
        A flag indicating whether a possibly existing content (and its data) shall be overwritten.
        
        Implementations that are not able to detect whether there are previous data may ignore this parameter and will always write the new data.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..beans.named_value import NamedValue as NamedValue_a37a0af3
from ..util.url import URL as URL_57ad07b9


class ControlEvent(object):
    """
    Struct Class

    describes a control event sent by extended user interface controls.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API ControlEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1ControlEvent.html>`_
    """
    typeName: Literal['com.sun.star.frame.ControlEvent']

    def __init__(self, aInformation: typing.Optional[typing.Tuple[NamedValue_a37a0af3, ...]] = ..., aURL: typing.Optional[URL_57ad07b9] = ..., Event: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            aInformation (typing.Tuple[NamedValue, ...], optional): aInformation value.
            aURL (URL, optional): aURL value.
            Event (str, optional): Event value.
        """


    @property
    def aInformation(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        specifies a sequence of named values which are used as additional values for the event.
        
        The number and types of named values depend on the event.
        """


    @property
    def aURL(self) -> URL_57ad07b9:
        """
        fully parsed URL describing the control that sends this notification.
        """


    @property
    def Event(self) -> str:
        """
        specifies the event which has occurred.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal


class Months(object):
    """
    Const

    Constants for month names used in calls to XCalendar.getDisplayName().

    See Also:
        `API Months <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html>`_
    """
    JANUARY: Literal[0]
    """
    January.
    """
    FEBURARY: Literal[1]
    """
    February.
    """
    MARCH: Literal[2]
    """
    March.
    """
    APRIL: Literal[3]
    """
    April.
    """
    MAY: Literal[4]
    """
    May.
    """
    JUNE: Literal[5]
    """
    June.
    """
    JULY: Literal[6]
    """
    July.
    """
    AUGUST: Literal[7]
    """
    August.
    """
    SEPTEMBER: Literal[8]
    """
    September.
    """
    OCTOBER: Literal[9]
    """
    October.
    """
    NOVEMBER: Literal[10]
    """
    November.
    """
    DECEMBER: Literal[11]
    """
    December.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .numbered_sorting_info import NumberedSortingInfo as NumberedSortingInfo_fd0e0de6
    from .x_any_compare_factory import XAnyCompareFactory as XAnyCompareFactory_ec090d61
    from .x_dynamic_result_set import XDynamicResultSet as XDynamicResultSet_e0360d0a

class XCachedDynamicResultSetStubFactory(XInterface_8f010a43):
    """
    creates a CachedDynamicResultSetStub and connects a non-remote optimized DynamicResultSet to a remote optimized CachedDynamicResultSet.
    
    Pay attention to instantiate this helper on server side where your source DynamicResultSet was instantiated.
    
    Method XCachedDynamicResultSetStubFactory.createCachedDynamicResultSetStub() can be used to create a stub on server side.
    
    If you have instantiated a CachedDynamicResultSet on client side already, use method connectToCache() to connect your given DynamicResultSet with this Cache.
    
    The needed cache on server side you can create using XCachedDynamicResultSetFactory.

    See Also:
        `API XCachedDynamicResultSetStubFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XCachedDynamicResultSetStubFactory.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XCachedDynamicResultSetStubFactory']

    def connectToCache(self, Source: 'XDynamicResultSet_e0360d0a', TargetCache: 'XDynamicResultSet_e0360d0a', SortingInfo: 'typing.Tuple[NumberedSortingInfo_fd0e0de6, ...]', CompareFactory: 'XAnyCompareFactory_ec090d61') -> None:
        """
        If you have instantiated a CachedDynamicResultSet on client side already, use this to connect your given Source on server side to the TargetCache.

        Raises:
            : ````
            com.sun.star.ucb.AlreadyInitializedException: ``AlreadyInitializedException``
        """
    def createCachedDynamicResultSetStub(self, Source: 'XDynamicResultSet_e0360d0a') -> 'XDynamicResultSet_e0360d0a':
        """
        creates a remote optimizes XDynamicResultSet.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from ..container.x_hierarchical_name_access import XHierarchicalNameAccess as XHierarchicalNameAccess_9e2611b5
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..util.x_changes_notifier import XChangesNotifier as XChangesNotifier_e1b50d17

class HierarchyDataReadAccess(XHierarchicalNameAccess_9e2611b5, XNameAccess_e2ab0cf6, XComponent_98dc0ab5, XChangesNotifier_e1b50d17):
    """
    Service Class

    provides read access to a fragment of the hierarchy data.
    
    A hierarchy data source provides access to a tree of hierarchy data nodes. Each hierarchy data node, except the root node, has a parent that is a hierarchy data node too. A hierarchy data node has a name.
    
    Each hierarchy data node has three data members:

    See Also:
        `API HierarchyDataReadAccess <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1HierarchyDataReadAccess.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal


class RuleAction(object):
    """
    Const

    These are the possible values for Rule.Action.

    See Also:
        `API RuleAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1RuleAction.html>`_
    """
    NONE: Literal[0]
    """
    \"None\" - Do nothing.
    """
    SHOW: Literal[1]
    """
    \"Show\" - Shows object when term matches.
    """
    HIDE: Literal[2]
    """
    \"Hide\" - Hides object when term matches.
    """
    MARK: Literal[3]
    """
    \"Mark\" - Marks object when term matches.
    """
    UNMARK: Literal[4]
    """
    \"UnMark\" - Removes mark from object when term matches.
    """
    MARKREAD: Literal[5]
    """
    \"MarkRead\" - Marks object as read when term matches.
    """
    MARKUNREAD: Literal[6]
    """
    \"MarkUnRead\" - Marks object as not read when term matches.
    """
    MOVE: Literal[7]
    """
    \"Move\" - Moves object to Rule.Parameter when term matches.
    """
    COPY: Literal[8]
    """
    \"Copy\" - Copies object to Rule.Parameter when term matches.
    """
    DELETE: Literal[9]
    """
    \"Delete\" - Deletes object when term matches.
    """
    LINK: Literal[10]
    """
    \"Link\" - Creates a link to Rule.Parameter when term matches.
    """
    FORWARD: Literal[11]
    """
    \"Forward\" - Forwards object to Rule.Parameter when term matches.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_sheet_cell_ranges import XSheetCellRanges as XSheetCellRanges_edef0d52
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XCellRangesQuery(XInterface_8f010a43):
    """
    provides methods to query for cell ranges with specific contents.
    
    All methods return a collection of cell ranges.

    See Also:
        `API XCellRangesQuery <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangesQuery.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XCellRangesQuery']

    def queryColumnDifferences(self, aCompare: 'CellAddress_ae5f0b56') -> 'XSheetCellRanges_edef0d52':
        """
        queries all cells with different values in a specified row.
        
        This method takes each column of the current cell range(s) and compares all cells with the cell in the specified row. All cells which are different to this comparison cell will be returned.
        """
    def queryContentCells(self, nContentFlags: int) -> 'XSheetCellRanges_edef0d52':
        """
        queries all cells with the specified content type(s).
        
        Attention: Despite the CellFlags flags are long values, this method expects a short parameter.
        
        Attention: Empty cells in the range may be skipped depending on the content flag used. For instance, when querying for STYLES, the returned ranges may not include empty cells even if styles are applied to those cells.
        """
    def queryEmptyCells(self) -> 'XSheetCellRanges_edef0d52':
        """
        queries all empty cells.
        """
    def queryFormulaCells(self, nResultFlags: int) -> 'XSheetCellRanges_edef0d52':
        """
        queries all formula cells with the specified result type.
        """
    def queryIntersection(self, aRange: 'CellRangeAddress_ec450d43') -> 'XSheetCellRanges_edef0d52':
        """
        intersects the current cell range(s) with the specified cell range.
        """
    def queryRowDifferences(self, aCompare: 'CellAddress_ae5f0b56') -> 'XSheetCellRanges_edef0d52':
        """
        queries all cells with different values in a specified column.
        
        This method takes each row of the current cell range(s) and compares all cells with the cell in the specified column. All cells which are different to this comparison cell will be returned.
        """
    def queryVisibleCells(self) -> 'XSheetCellRanges_edef0d52':
        """
        queries all visible cells.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .point_sequence_sequence import PointSequenceSequence as PointSequenceSequence_5c591070
    from .polygon_kind import PolygonKind as PolygonKind_ca6f0c62

class PolyPolygonDescriptor(ABC):
    """
    Service Class

    This service describes a poly-polygon.
    
    A poly-polygon consists of multiple polygons combined in one.

    See Also:
        `API PolyPolygonDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonDescriptor.html>`_
    """
    @property
    def Geometry(self) -> 'PointSequenceSequence_5c591070':
        """
        These are the untransformed points of this polygon.
        """
    @property
    def PolyPolygon(self) -> 'PointSequenceSequence_5c591070':
        """
        These are the reference points for this polygon.
        """
    @property
    def PolygonKind(self) -> 'PolygonKind_ca6f0c62':
        """
        This is the type of polygon.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.uri
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XUriReference(XInterface_8f010a43):
    """
    represents generic, mutable URI references.
    
    See RFC 3986 for a description of URI references and related terms.
    
    This interface only handles generic URI references (both absolute and relative). For specific URI schemes, there will be additional interfaces that offer extra, scheme-specific functionality.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XUriReference <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.uri.XUriReference']

    def clearFragment(self) -> None:
        """
        clears the fragment part of this URI reference.
        """
    def getAuthority(self) -> str:
        """
        returns the authority part of this URI reference.
        """
    def getFragment(self) -> str:
        """
        returns the fragment part of this URI reference.
        """
    def getPath(self) -> str:
        """
        returns the path part of this URI reference.
        """
    def getPathSegment(self, index: int) -> str:
        """
        returns a given path segment of this URI reference.
        """
    def getPathSegmentCount(self) -> int:
        """
        returns the number of path segments of this URI reference.
        
        For a URI reference with an empty path, the number of path segments is zero. For a URI reference with an absolute, non-empty path, the number of path segments equals the number of “/” delimiters. For a URI reference with a relative, non-empty path, the number of path segments equals the number of “/” delimiters, plus one.
        """
    def getQuery(self) -> str:
        """
        returns the query part of this URI reference.
        """
    def getScheme(self) -> str:
        """
        returns the scheme part of this (absolute) URI reference.
        """
    def getSchemeSpecificPart(self) -> str:
        """
        returns the scheme-specific part of this URI reference.
        
        For an absolute URI reference, the scheme-specific part is everything after the scheme part and the delimiting “:”, and before the optional “#” and fragment part. For a relative URI reference, the scheme-specific part is everything before the optional “#” and fragment part.
        """
    def getUriReference(self) -> str:
        """
        returns the textual representation of the complete URI reference.
        """
    def hasAuthority(self) -> bool:
        """
        returns whether this URI reference has an authority part.
        """
    def hasFragment(self) -> bool:
        """
        returns whether this URI reference has a fragment part.
        """
    def hasQuery(self) -> bool:
        """
        returns whether this URI reference has a query part.
        """
    def hasRelativePath(self) -> bool:
        """
        returns whether this URI reference has a relative path.
        """
    def isAbsolute(self) -> bool:
        """
        returns whether this URI reference is absolute or relative.
        
        A URI is absolute if it has a scheme.
        """
    def isHierarchical(self) -> bool:
        """
        returns whether this URI reference is hierarchical or opaque, in the sense of RFC&nbsp2396.
        
        An absolute URI reference is hierarchical if its scheme-specific part starts with “/”. A relative URI reference is always hierarchical.
        """
    def setFragment(self, fragment: str) -> None:
        """
        sets the fragment part of this URI reference.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
from ..awt.uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
from ..beans.x_fast_property_set import XFastPropertySet as XFastPropertySet_ee6b0d88
from ..beans.x_property_state import XPropertyState as XPropertyState_d55c0ccf
from .form_component import FormComponent as FormComponent_bc700c03

class FormControlModel(UnoControlModel_c8ce0c58, FormComponent_bc700c03, XFastPropertySet_ee6b0d88, XPropertyState_d55c0ccf):
    """
    Service Class

    specifies a control model within a form.
    
    Note that the model-view-paradigm is used for form controls, too.

    See Also:
        `API FormControlModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1FormControlModel.html>`_
    """
    @property
    def ClassId(self) -> int:
        """
        specifies the ID for classification of the component.
        """
    @property
    def TabIndex(self) -> int:
        """
        determines the relative taborder of the control associated with the model.
        
        The default -1 is used to indicate that the tab-order of this control should be determined automatically.
        
        Each component which supports a tabstop must provide a FormControlModel.TabIndex property.
        
        Normally, a FormController instance is evaluating this property.
        """
    @property
    def Tag(self) -> str:
        """
        used for additional information.
        
        No semantics is given for this property, it will usually be used by the creator of a document containing form controls.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .sort_field_type import SortFieldType as SortFieldType_bd500bf4


class SortField(object):
    """
    Struct Class

    describes a single field in a sort descriptor.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API SortField <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1SortField.html>`_
    """
    typeName: Literal['com.sun.star.util.SortField']

    def __init__(self, Field: typing.Optional[int] = ..., SortAscending: typing.Optional[bool] = ..., FieldType: typing.Optional[SortFieldType_bd500bf4] = ...) -> None:
        """
        Constructor

        Arguments:
            Field (int, optional): Field value.
            SortAscending (bool, optional): SortAscending value.
            FieldType (SortFieldType, optional): FieldType value.
        """


    @property
    def Field(self) -> int:
        """
        index of the field in the table; 0-based.
        """


    @property
    def SortAscending(self) -> bool:
        """
        TRUE if data are sorted in ascending order, FALSE if in descending order.
        """


    @property
    def FieldType(self) -> SortFieldType_bd500bf4:
        """
        type of contents in the field.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.linguistic2
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..beans.property_value import PropertyValue as PropertyValue_c9610c73


class SingleProofreadingError(object):
    """
    Struct Class

    holds a single error found by the proofreader.
    
    **since**
    
        OOo 3.0.1

    See Also:
        `API SingleProofreadingError <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1linguistic2_1_1SingleProofreadingError.html>`_
    """
    typeName: Literal['com.sun.star.linguistic2.SingleProofreadingError']

    def __init__(self, aSuggestions: typing.Optional[typing.Tuple[str, ...]] = ..., aProperties: typing.Optional[typing.Tuple[PropertyValue_c9610c73, ...]] = ..., nErrorStart: typing.Optional[int] = ..., nErrorLength: typing.Optional[int] = ..., nErrorType: typing.Optional[int] = ..., aRuleIdentifier: typing.Optional[str] = ..., aShortComment: typing.Optional[str] = ..., aFullComment: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            aSuggestions (typing.Tuple[str, ...], optional): aSuggestions value.
            aProperties (typing.Tuple[PropertyValue, ...], optional): aProperties value.
            nErrorStart (int, optional): nErrorStart value.
            nErrorLength (int, optional): nErrorLength value.
            nErrorType (int, optional): nErrorType value.
            aRuleIdentifier (str, optional): aRuleIdentifier value.
            aShortComment (str, optional): aShortComment value.
            aFullComment (str, optional): aFullComment value.
        """


    @property
    def aSuggestions(self) -> typing.Tuple[str, ...]:
        ...


    @property
    def aProperties(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        ...


    @property
    def nErrorStart(self) -> int:
        ...


    @property
    def nErrorLength(self) -> int:
        ...


    @property
    def nErrorType(self) -> int:
        ...


    @property
    def aRuleIdentifier(self) -> str:
        ...


    @property
    def aShortComment(self) -> str:
        ...


    @property
    def aFullComment(self) -> str:
        ...





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa
    from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
    from .x_hyphenator import XHyphenator as XHyphenator_ff4e0def
    from .x_spell_checker import XSpellChecker as XSpellChecker_1af30e82
    from .x_thesaurus import XThesaurus as XThesaurus_f1790d91

class XLinguServiceManager(XInterface_8f010a43):
    """
    the basic interface to be used to access linguistic functionality.
    
    This interface is used to access spell checker, hyphenator, and thesaurus functionality. Additionally, it can query what implementations of those services are available (for specific languages or in general). It can select and query which of those implementations should be used for a specific language.
    
    For spell checking and thesaurus, the order in the list defines the order of creation/usage of those services. That is, if the first spell checker implementation does not recognize the given word as correct, the second service implementation for that language is created and gets queried. If that one fails, the third one gets created and queried and so on. This chain stops if an implementation reports the word as correct or the end of the list is reached, in which case the word is reported as incorrect.
    
    For the thesaurus, the behavior is the same when no meaning was found.

    See Also:
        `API XLinguServiceManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguServiceManager.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.linguistic2.XLinguServiceManager']

    def addLinguServiceManagerListener(self, xListener: 'XEventListener_c7230c4a') -> bool:
        """
        adds a listener to the list of event listeners.
        
        The listeners may support one or both of com.sun.star.linguistic2.XDictionaryEventListener and com.sun.star.linguistic2.XLinguServiceEventListener interfaces.
        """
    def getAvailableServices(self, aServiceName: str, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[str, ...]':
        """
        """
    def getConfiguredServices(self, aServiceName: str, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[str, ...]':
        """
        queries the list of service implementations to be used for a given service and language.
        """
    def getHyphenator(self) -> 'XHyphenator_ff4e0def':
        """
        """
    def getSpellChecker(self) -> 'XSpellChecker_1af30e82':
        """
        """
    def getThesaurus(self) -> 'XThesaurus_f1790d91':
        """
        """
    def removeLinguServiceManagerListener(self, xListener: 'XEventListener_c7230c4a') -> bool:
        """
        removes a listener from the list of event listeners.
        """
    def setConfiguredServices(self, aServiceName: str, aLocale: 'Locale_70d308fa', aServiceImplNames: 'typing.Tuple[str, ...]') -> None:
        """
        sets the list of service implementations to be used for a given service and language.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ..._pyi.text.textfield.annotation import Annotation as Annotation
from ..._pyi.text.textfield.author import Author as Author
from ..._pyi.text.textfield.bibliography import Bibliography as Bibliography
from ..._pyi.text.textfield.chapter import Chapter as Chapter
from ..._pyi.text.textfield.character_count import CharacterCount as CharacterCount
from ..._pyi.text.textfield.combined_characters import CombinedCharacters as CombinedCharacters
from ..._pyi.text.textfield.conditional_text import ConditionalText as ConditionalText
from ..._pyi.text.textfield.dde import DDE as DDE
from ..._pyi.text.textfield.database import Database as Database
from ..._pyi.text.textfield.database_name import DatabaseName as DatabaseName
from ..._pyi.text.textfield.database_next_set import DatabaseNextSet as DatabaseNextSet
from ..._pyi.text.textfield.database_number_of_set import DatabaseNumberOfSet as DatabaseNumberOfSet
from ..._pyi.text.textfield.database_set_number import DatabaseSetNumber as DatabaseSetNumber
from ..._pyi.text.textfield.date_time import DateTime as DateTime
from ..._pyi.text.textfield.drop_down import DropDown as DropDown
from ..._pyi.text.textfield.embedded_object_count import EmbeddedObjectCount as EmbeddedObjectCount
from ..._pyi.text.textfield.extended_user import ExtendedUser as ExtendedUser
from ..._pyi.text.textfield.file_name import FileName as FileName
from ..._pyi.text.textfield.get_expression import GetExpression as GetExpression
from ..._pyi.text.textfield.get_reference import GetReference as GetReference
from ..._pyi.text.textfield.graphic_object_count import GraphicObjectCount as GraphicObjectCount
from ..._pyi.text.textfield.hidden_paragraph import HiddenParagraph as HiddenParagraph
from ..._pyi.text.textfield.hidden_text import HiddenText as HiddenText
from ..._pyi.text.textfield.input import Input as Input
from ..._pyi.text.textfield.input_user import InputUser as InputUser
from ..._pyi.text.textfield.jump_edit import JumpEdit as JumpEdit
from ..._pyi.text.textfield.macro import Macro as Macro
from ..._pyi.text.textfield.metadata_field import MetadataField as MetadataField
from ..._pyi.text.textfield.page_count import PageCount as PageCount
from ..._pyi.text.textfield.page_number import PageNumber as PageNumber
from ..._pyi.text.textfield.paragraph_count import ParagraphCount as ParagraphCount
from ..._pyi.text.textfield.reference_page_get import ReferencePageGet as ReferencePageGet
from ..._pyi.text.textfield.reference_page_set import ReferencePageSet as ReferencePageSet
from ..._pyi.text.textfield.script import Script as Script
from ..._pyi.text.textfield.set_expression import SetExpression as SetExpression
from ..._pyi.text.textfield.table_count import TableCount as TableCount
from ..._pyi.text.textfield.table_formula import TableFormula as TableFormula
from ..._pyi.text.textfield.template_name import TemplateName as TemplateName
from ..._pyi.text.textfield.url import URL as URL
from ..._pyi.text.textfield.user import User as User
from ..._pyi.text.textfield.word_count import WordCount as WordCount



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.component
import typing
from ..data_aware_control_model import DataAwareControlModel as DataAwareControlModel_27110ef8
from .list_box import ListBox as ListBox_f1530d82
if typing.TYPE_CHECKING:
    from ..list_source_type import ListSourceType as ListSourceType_c9850c6b

class DatabaseListBox(DataAwareControlModel_27110ef8, ListBox_f1530d82):
    """
    Service Class

    This service specifies a data-aware list box control model.
    
    The base service for list boxes (ListBox) offers only one possibility to specify the list entries: The display strings in the com.sun.star.awt.UnoControlListBoxModel.StringItemList property and the corresponding values in the ListBox.ListSource property.
    
    This service here extends this mimic. It allows to fill the list from a data source. This means that a second result set is opened, which works on the same connection as the form which the list box belongs to, but can be based on an arbitrary table or SQL statement.
    
    For instance, you may have a form which is bound to a table invoice, and you use it to enter invoices for your customers. Probably, you will have a second table (say customer), which (among other data) contains a unique key for identifying customers. In your invoice table, you will have a foreign key referring to these customers.
    Now, besides the result set the form is based on (all your invoices), the list box can be instructed to open a second result set, this time for the customer table, and fill its list with entries from this result set.
    Additionally, it allows to model the relation between the two tables: When the user selects a customer from the list, this customer has the unique id we just talked about (which is not necessarily visible to the user in any way). The list box then automatically transfers this id into the foreign key column of invoice, thus allowing the user to transparently work with human-readable strings instead of pure numbers.
    Let's call this result set the list is filled from the list result set here ...
    
    The display strings are always taken from the first column of that result set, and the corresponding value as per the BoundColumn property.

    See Also:
        `API DatabaseListBox <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox.html>`_
    """
    @property
    def SelectedValues(self) -> 'typing.Tuple[object, ...]':
        """
        The selected values.
        """
    @property
    def BoundColumn(self) -> int:
        """
        specifies which column of the list result set should be used for data exchange.
        
        When you make a selection from a list box, the \"BoundColumn\" property reflects which column value of a result set should be used as the value of the component. If the control is bound to a database field, the column value is stored in the database field identified by the property com.sun.star.form.DataAwareControlModel.DataField.
        
        The bound column property is only used if a list source is defined and the list source matches with the types com.sun.star.form.ListSourceType.TABLE, com.sun.star.form.ListSourceType.QUERY, com.sun.star.form.ListSourceType.SQL or com.sun.star.form.ListSourceType.SQLPASSTHROUGH. Otherwise the property is ignored, as there is no result set from which to get the column values.
        """
    @property
    def ListSourceType(self) -> 'ListSourceType_c9850c6b':
        """
        describes the kind of list source used.
        
        Depending on the value of this property, the way the value of ListBox.ListSource is evaluated varies.
        """
    @property
    def SelectedValue(self) -> object:
        """
        The selected value, if there is at most one.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
from .x_shapes import XShapes as XShapes_9a800ab0

class ShapeCollection(XShapes_9a800ab0):
    """
    Service Class

    This service describes a generic container to manage collections of Shape.
    
    The Shape that are added to this collection are not owned by the collection.
    
    This service is used by the view f.e. to return a collection of Shape that are selected at the ui.

    See Also:
        `API ShapeCollection <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1ShapeCollection.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_control_model import XControlModel as XControlModel_affc0b7e

class XTabControllerModel(XInterface_8f010a43):
    """
    specifies the basic operations for a tab controller model.

    See Also:
        `API XTabControllerModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XTabControllerModel.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XTabControllerModel']

    def getControlModels(self) -> 'typing.Tuple[XControlModel_affc0b7e, ...]':
        """
        returns the control models.
        """
    def getGroup(self, nGroup: int, Group: 'typing.Tuple[XControlModel_affc0b7e, ...]', Name: str) -> None:
        """
        returns a control model group.

        * ``Group`` is an out direction argument.
        * ``Name`` is an out direction argument.
        """
    def getGroupByName(self, Name: str, Group: 'typing.Tuple[XControlModel_affc0b7e, ...]') -> None:
        """
        returns a control model group by name.

        * ``Group`` is an out direction argument.
        """
    def getGroupControl(self) -> bool:
        """
        returns whether the control models are grouped together.
        """
    def getGroupCount(self) -> int:
        """
        returns the number of control model groups.
        """
    def setControlModels(self, Controls: 'typing.Tuple[XControlModel_affc0b7e, ...]') -> None:
        """
        sets the control models.
        """
    def setGroup(self, Group: 'typing.Tuple[XControlModel_affc0b7e, ...]', GroupName: str) -> None:
        """
        sets a control model group.
        """
    def setGroupControl(self, GroupControl: bool) -> None:
        """
        determines if the control models are grouped together.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .horizontal_adjust import HorizontalAdjust as HorizontalAdjust_e57e0d62

class PageFootnoteInfo(ABC):
    """
    Service Class

    specifies the properties of the footnote area of a page or a page style.

    See Also:
        `API PageFootnoteInfo <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1PageFootnoteInfo.html>`_
    """
    @property
    def FootnoteBottomDistance(self) -> int:
        """
        contains the distance between the separator line and the footnote section.
        """
    @property
    def FootnoteHeight(self) -> int:
        """
        contains the maximum height of the footnote section.
        
        If 0, the maximum is the height of the page.
        """
    @property
    def FootnoteSeparatorLineAdjust(self) -> 'HorizontalAdjust_e57e0d62':
        """
        contains the adjustment of the footnote separator line.
        """
    @property
    def FootnoteSeparatorLinePenWidth(self) -> int:
        """
        contains the width of the pen for the footnote separator line.
        """
    @property
    def FootnoteSeparatorLineWidth(self) -> int:
        """
        contains the relative width of the footnote separator line.
        """
    @property
    def FootnoteSeparatorLineWidthPercent(self) -> int:
        """
        contains the relative width of the footnote separator line.
        """
    @property
    def FootnoteTopDistance(self) -> int:
        """
        contains the distance between the text and footnote section.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.xml.crypto
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...security.x_certificate import XCertificate as XCertificate_e55b0d3b

class XCertificateCreator(XInterface_8f010a43):
    """
    Interface for creating and adding certificates.
    
    **since**
    
        LibreOffice 6.2

    See Also:
        `API XCertificateCreator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XCertificateCreator.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.crypto.XCertificateCreator']

    def addDERCertificateToTheDatabase(self, aDerCertificate: 'typing.Tuple[int, ...]', aTrustString: str) -> 'XCertificate_e55b0d3b':
        """
        Adds a certificate to the certificate database with the trust provided by the trust string.
        """
    def createDERCertificateWithPrivateKey(self, aDerCertificate: 'typing.Tuple[int, ...]', aPrivateKey: 'typing.Tuple[int, ...]') -> 'XCertificate_e55b0d3b':
        """
        Create certificate from raw DER encoded certificate and associate the private key with the certificate.

        Raises:
            com.sun.star.uno.SecurityException: ``SecurityException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
import typing
from .x_poly_polygon2_d import XPolyPolygon2D as XPolyPolygon2D_e1b0e20
if typing.TYPE_CHECKING:
    from ..geometry.real_point2_d import RealPoint2D as RealPoint2D_d6e70c78

class XLinePolyPolygon2D(XPolyPolygon2D_e1b0e20):
    """
    Specialized interface for a 2D poly-polygon containing only straight line segments.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XLinePolyPolygon2D <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XLinePolyPolygon2D.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rendering.XLinePolyPolygon2D']

    def getPoint(self, nPolygonIndex: int, nPointIndex: int) -> 'RealPoint2D_d6e70c78':
        """
        Get a single point from the poly-polygon.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getPoints(self, nPolygonIndex: int, nNumberOfPolygons: int, nPointIndex: int, nNumberOfPoints: int) -> 'typing.Tuple[typing.Tuple[RealPoint2D_d6e70c78, ...], ...]':
        """
        Query subset of this poly-polygon, starting at the given polygon and the given point within that polygon, and containing the specified number of polygons and points in the last polygon.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setPoint(self, point: 'RealPoint2D_d6e70c78', nPolygonIndex: int, nPointIndex: int) -> None:
        """
        Set a single point on the poly-polygon.
        
        The remaining points of the poly-polygon will not be changed by this method.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setPoints(self, points: 'typing.Tuple[typing.Tuple[RealPoint2D_d6e70c78, ...], ...]', nPolygonIndex: int) -> None:
        """
        Set the specified sequence of points to the poly-polygon.
        
        This method can either set the whole poly-polygon to the new data, or insert the points at the given index

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43

class DuplicateCommandIdentifierException(Exception_85530a09):
    """
    Exception Class

    is thrown by XCommandProcessor.execute() to indicate that the same command identifier was used for two threads.
    
    Each thread must use its own command identifier, which must be obtained using XCommandProcessor.createCommandIdentifier(). Command identifier 0, which indicates that the command shall never be aborted by a client, can be used by any thread.

    See Also:
        `API DuplicateCommandIdentifierException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1ucb_1_1DuplicateCommandIdentifierException.html>`_
    """

    typeName: Literal['com.sun.star.ucb.DuplicateCommandIdentifierException']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
        """

__all__ = ['DuplicateCommandIdentifierException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal


class KParseType(object):
    """
    Const

    Constants to specify the type of a parsed token.
    
    Set by XCharacterClassification.parseAnyToken() and XCharacterClassification.parsePredefinedToken() in ParseResult.TokenType.

    See Also:
        `API KParseType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1KParseType.html>`_
    """
    ONE_SINGLE_CHAR: Literal[1]
    """
    One single character like ! # ; : $ et al.
    """
    BOOLEAN: Literal[2]
    """
    A Boolean operator like <, >, <>, =, <=, >=.
    """
    IDENTNAME: Literal[4]
    """
    A name matching the conditions passed.
    """
    SINGLE_QUOTE_NAME: Literal[8]
    """
    \"A single-quoted name matching the conditions passed ( 'na\\'me' ).\" \"Dequoted name in ParseResult.DequotedNameOrString ( na'me ).\"
    """
    DOUBLE_QUOTE_STRING: Literal[16]
    """
    A double-quoted string ( \"str\\\"i\"\"ng\" ).
    
    Dequoted string in ParseResult.DequotedNameOrString ( str\"i\"ng ).
    """
    ASC_NUMBER: Literal[32]
    """
    A number where all digits are ASCII characters.
    
    Numerical value in ParseResult.Value.
    """
    UNI_NUMBER: Literal[64]
    """
    A number where at least some digits are Unicode (and maybe ASCII) characters.
    
    Numerical value inKParseType ParseResult.Value.
    """
    MISSING_QUOTE: Literal[1073741824]
    """
    Set (ored) if SINGLE_QUOTE_NAME or DOUBLE_QUOTE_STRING has no closing quote.
    """
    ANY_NUMBER: str
    """
    Any ASCII or Unicode number.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from abc import ABC

class PagePrintSettings(ABC):
    """
    Service Class

    These properties describe the way the XPagePrintable interface prints the page on one printer page.

    See Also:
        `API PagePrintSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1PagePrintSettings.html>`_
    """
    @property
    def BottomMargin(self) -> int:
        """
        contains the right margin of the printer page.
        """
    @property
    def HoriMargin(self) -> int:
        """
        contains the margin between the rows of printed pages.
        """
    @property
    def IsLandscape(self) -> bool:
        """
        defines if the printer page is used in landscape format.
        """
    @property
    def LeftMargin(self) -> int:
        """
        contains the left margin of the printer page.
        """
    @property
    def PageColumns(self) -> int:
        """
        contains the number of pages per printed row of pages.
        """
    @property
    def PageRows(self) -> int:
        """
        contains the number of pages per printed column of pages.
        """
    @property
    def RightMargin(self) -> int:
        """
        contains the right margin of the printer page.
        """
    @property
    def TopMargin(self) -> int:
        """
        contains the top margin of the printer page.
        """
    @property
    def VertMargin(self) -> int:
        """
        contains the margin between the columns of printed pages.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.io
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .io_exception import IOException as IOException_8c450a27
from ..uno.x_interface import XInterface as XInterface_8f010a43

class BufferSizeExceededException(IOException_8c450a27):
    """
    Exception Class

    is thrown by instances which need to buffer data.
    
    It indicates that not enough system resources are available for extending the buffer. (May also indicate that the internal buffer has grown to a larger size than 2G. Some current implementations do not support larger buffers.)

    See Also:
        `API BufferSizeExceededException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1io_1_1BufferSizeExceededException.html>`_
    """

    typeName: Literal['com.sun.star.io.BufferSizeExceededException']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
        """

__all__ = ['BufferSizeExceededException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
from ..frame.x_controller import XController as XController_b00e0b8f
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca

class QueryDesign(XController_b00e0b8f, XInitialization_d46c0cca):
    """
    Service Class

    implements a component which allows the creation of SQL statements.
    
    This service implements a user interface for creating SQL statements either through a graphical design interface or simply to enter the SQL statement directly.
    
    The design view of the QueryDesign is divided into two parts. The first part contains the table windows where columns can be selected for the SQL statement. The second part contains the columns which should appear in the selection of the SQL statement or criteria which narrow the query.
    
    A QueryDesign component has 3 operation modes, which control what kind of object is edited:
    
    Initialization is done using the com.sun.star.lang.XInitialization interface, which expects a sequence of objects being either com.sun.star.beans.NamedValues or com.sun.star.beans.PropertyValues. The following parameters are supported at initialization time:
    
    There's a number of legacy settings which are recognized for compatibility reasons, though you're discouraged from using them:
    
    **since**
    
        OOo 2.4

    See Also:
        `API QueryDesign <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1QueryDesign.html>`_
    """
    @property
    def ActiveCommand(self) -> str:
        """
        reflects the designed SQL command at the moment it was last saved by the user.
        """
    @property
    def EscapeProcessing(self) -> bool:
        """
        specifies whether the user enabled escape processing for the statement being designed.
        
        **since**
        
            OOo 2.4
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43

class TerminationVetoException(Exception_85530a09):
    """
    Exception Class

    can be thrown by a XTerminateListener to prevent the environment (e.g., desktop) from terminating
    
    If a XTerminateListener use this exception for a veto against the termination of the office, he will be the new \"owner\" of it. After his own operation will be finished, he MUST try to terminate the office again. Any other veto listener can intercept that again or office will die really.
    
    Since LibreOffice 5.3: Throwing this exception will only prevent termination. Exiting LibreOffice will close all the windows, but the process will keep running.

    See Also:
        `API TerminationVetoException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1frame_1_1TerminationVetoException.html>`_
    """

    typeName: Literal['com.sun.star.frame.TerminationVetoException']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
        """

__all__ = ['TerminationVetoException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui.dialogs
import typing
from .x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1
if typing.TYPE_CHECKING:
    from ...awt.x_window import XWindow as XWindow_713b0924

class AddressBookSourcePilot(XExecutableDialog_450f0fa1):
    """
    Service Class

    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API AddressBookSourcePilot <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1AddressBookSourcePilot.html>`_
    """
    def createWithParent(self, ParentWindow: 'XWindow_713b0924') -> None:
        """
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
import typing
from .x_interface_member_type_description import XInterfaceMemberTypeDescription as XInterfaceMemberTypeDescription_52ea159a
if typing.TYPE_CHECKING:
    from .x_method_parameter import XMethodParameter as XMethodParameter_3b120f8d
    from .x_type_description import XTypeDescription as XTypeDescription_3c210fb1

class XInterfaceMethodTypeDescription(XInterfaceMemberTypeDescription_52ea159a):
    """
    Reflects an interface method type.
    
    The type class of this type is TypeClass_INTERFACE_METHOD.

    See Also:
        `API XInterfaceMethodTypeDescription <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceMethodTypeDescription.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XInterfaceMethodTypeDescription']

    def getExceptions(self) -> 'typing.Tuple[XTypeDescription_3c210fb1, ...]':
        """
        Returns declared exceptions that may occur upon invocations of the method.
        """
    def getParameters(self) -> 'typing.Tuple[XMethodParameter_3b120f8d, ...]':
        """
        Returns all parameters of the method in order of IDL declaration.
        """
    def getReturnType(self) -> 'XTypeDescription_3c210fb1':
        """
        Returns the method's return type.
        """
    def isOneway(self) -> bool:
        """
        Returns true, if this method is declared oneway.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
from enum import Enum

class UnicodeScript(Enum):
    """
    Enum

    

    See Also:
        `API UnicodeScript <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29>`_
    """

    kAlphabeticPresentation: 'uno.Enum'
    """
    """
    kArabic: 'uno.Enum'
    """
    """
    kArabicPresentationA: 'uno.Enum'
    """
    """
    kArabicPresentationB: 'uno.Enum'
    """
    """
    kArmenian: 'uno.Enum'
    """
    """
    kArrow: 'uno.Enum'
    """
    """
    kBasicLatin: 'uno.Enum'
    """
    """
    kBengali: 'uno.Enum'
    """
    """
    kBlockElement: 'uno.Enum'
    """
    """
    kBopomofo: 'uno.Enum'
    """
    """
    kBopomofoExtended: 'uno.Enum'
    """
    """
    kBoxDrawing: 'uno.Enum'
    """
    """
    kBraillePatterns: 'uno.Enum'
    """
    """
    kCJKCompatibility: 'uno.Enum'
    """
    """
    kCJKCompatibilityForm: 'uno.Enum'
    """
    """
    kCJKCompatibilityIdeograph: 'uno.Enum'
    """
    """
    kCJKRadicalsSupplement: 'uno.Enum'
    """
    """
    kCJKSymbolPunctuation: 'uno.Enum'
    """
    """
    kCJKUnifiedIdeograph: 'uno.Enum'
    """
    """
    kCJKUnifiedIdeographsExtensionA: 'uno.Enum'
    """
    """
    kCherokee: 'uno.Enum'
    """
    """
    kCombiningDiacritical: 'uno.Enum'
    """
    """
    kCombiningHalfMark: 'uno.Enum'
    """
    """
    kControlPicture: 'uno.Enum'
    """
    """
    kCurrencySymbolScript: 'uno.Enum'
    """
    """
    kCyrillic: 'uno.Enum'
    """
    """
    kDevanagari: 'uno.Enum'
    """
    """
    kDingbat: 'uno.Enum'
    """
    """
    kEnclosedAlphanumeric: 'uno.Enum'
    """
    """
    kEnclosedCJKLetterMonth: 'uno.Enum'
    """
    """
    kEthiopic: 'uno.Enum'
    """
    """
    kGeneralPunctuation: 'uno.Enum'
    """
    """
    kGeometricShape: 'uno.Enum'
    """
    """
    kGeorgian: 'uno.Enum'
    """
    """
    kGreek: 'uno.Enum'
    """
    """
    kGreekExtended: 'uno.Enum'
    """
    """
    kGujarati: 'uno.Enum'
    """
    """
    kGurmukhi: 'uno.Enum'
    """
    """
    kHalfwidthFullwidthForm: 'uno.Enum'
    """
    """
    kHangulCompatibilityJamo: 'uno.Enum'
    """
    """
    kHangulJamo: 'uno.Enum'
    """
    """
    kHangulSyllable: 'uno.Enum'
    """
    """
    kHebrew: 'uno.Enum'
    """
    """
    kHighPrivateUseSurrogate: 'uno.Enum'
    """
    """
    kHighSurrogate: 'uno.Enum'
    """
    """
    kHiragana: 'uno.Enum'
    """
    """
    kIPAExtension: 'uno.Enum'
    """
    """
    kIdeographicDescriptionCharacters: 'uno.Enum'
    """
    """
    kKanbun: 'uno.Enum'
    """
    """
    kKangxiRadicals: 'uno.Enum'
    """
    """
    kKannada: 'uno.Enum'
    """
    """
    kKatakana: 'uno.Enum'
    """
    """
    kKhmer: 'uno.Enum'
    """
    """
    kLao: 'uno.Enum'
    """
    """
    kLatin1Supplement: 'uno.Enum'
    """
    """
    kLatinExtendedA: 'uno.Enum'
    """
    """
    kLatinExtendedAdditional: 'uno.Enum'
    """
    """
    kLatinExtendedB: 'uno.Enum'
    """
    """
    kLetterlikeSymbol: 'uno.Enum'
    """
    """
    kLowSurrogate: 'uno.Enum'
    """
    """
    kMalayalam: 'uno.Enum'
    """
    """
    kMathOperator: 'uno.Enum'
    """
    """
    kMiscSymbol: 'uno.Enum'
    """
    """
    kMiscTechnical: 'uno.Enum'
    """
    """
    kMongolian: 'uno.Enum'
    """
    """
    kMyanmar: 'uno.Enum'
    """
    """
    kNoScript: 'uno.Enum'
    """
    """
    kNumberForm: 'uno.Enum'
    """
    """
    kOgham: 'uno.Enum'
    """
    """
    kOpticalCharacter: 'uno.Enum'
    """
    """
    kOriya: 'uno.Enum'
    """
    """
    kPrivateUse: 'uno.Enum'
    """
    """
    kRunic: 'uno.Enum'
    """
    """
    kScriptCount: 'uno.Enum'
    """
    """
    kSinhala: 'uno.Enum'
    """
    """
    kSmallFormVariant: 'uno.Enum'
    """
    """
    kSpacingModifier: 'uno.Enum'
    """
    """
    kSuperSubScript: 'uno.Enum'
    """
    """
    kSymbolCombiningMark: 'uno.Enum'
    """
    """
    kSyriac: 'uno.Enum'
    """
    """
    kTamil: 'uno.Enum'
    """
    """
    kTelugu: 'uno.Enum'
    """
    """
    kThaana: 'uno.Enum'
    """
    """
    kThai: 'uno.Enum'
    """
    """
    kTibetan: 'uno.Enum'
    """
    """
    kUnifiedCanadianAboriginalSyllabics: 'uno.Enum'
    """
    """
    kYiRadicals: 'uno.Enum'
    """
    """
    kYiSyllables: 'uno.Enum'
    """
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .chart_data_change_event import ChartDataChangeEvent as ChartDataChangeEvent_25480ece

class XChartDataChangeEventListener(XEventListener_c7230c4a):
    """
    makes it possible to receive events when chart data changes.

    See Also:
        `API XChartDataChangeEventListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart_1_1XChartDataChangeEventListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart.XChartDataChangeEventListener']

    def chartDataChanged(self, aEvent: 'ChartDataChangeEvent_25480ece') -> None:
        """
        is called whenever chart data changes in value or structure.
        
        This interface must be implemented by components that wish to get notified of changes in chart data. They can be registered at an XChartData component.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal


class Error(object):
    """
    Const

    These codes are used to indicate errors.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API Error <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1Error.html>`_
    """
    NONE: Literal[0]
    LOGIN_FAILURE_RECEIVE: Literal[122880]
    LOGIN_FAILURE_NEWSSEND: Literal[122881]
    LOGIN_FAILURE_MAILSEND: Literal[122882]
    CONNECT_FAILURE: Literal[122883]
    UCB_OFFLINE: Literal[122884]
    UCB_SERVER_ERROR: Literal[122885]
    STORAGE_READONLY: Literal[122886]
    STORAGE_KILLED: Literal[122887]
    WRONG_FILE_FORMAT: Literal[122888]
    UNSUPPORTED_URL: Literal[122889]
    CNTOUT_NO_FROM: Literal[122890]
    TOO_MANY_GROUPS: Literal[122891]
    DELETE_ABORTED: Literal[122892]
    QUERY_DELETE: Literal[122893]
    NOTAVAILABLE: Literal[122894]
    VIM_LIBRARY_ERROR: Literal[122895]
    FOLDER_INVALID: Literal[122896]
    FTP_RESOLVERERROR: Literal[122897]
    FTP_NETWORKERROR: Literal[122898]
    FTP_NOTNECESSARYCMD: Literal[122899]
    FTP_SERVICEUNAVAILABLE: Literal[122900]
    FTP_DCONFAILURE: Literal[122901]
    FTP_TRANSFERABORTED: Literal[122902]
    NO_VIM_LIBRARY: Literal[122903]
    VIM_LIBRARY_CORRUPTED: Literal[122904]
    CCMAIL_EXPORT_ERROR: Literal[122905]
    NO_CCMAIL_EXPORT_FILE: Literal[122906]
    ILLEGAL_CCMAIL_EXPORT_FILE: Literal[122907]
    MESSAGE_NOT_FOUND: Literal[122908]
    BAD_CCMAIL_EXPORT_PASSWORD: Literal[122909]
    CCMAIL_EXPORT_TOO_LONG: Literal[122910]
    FOLDER_EXISTS: Literal[122911]
    FOLDER_NOT_EXISTS: Literal[122912]
    NO_VIM_BBOARDLIST: Literal[122913]
    ILLEGAL_MESSAGE_ID: Literal[122914]
    SERVER_PORT_SYNTAX: Literal[122915]
    SERVERNAME_SYNTAX: Literal[122916]
    USERNAME_SYNTAX: Literal[122917]
    IS_RESCHEDULED: Literal[122918]
    VIM_NO_FAKE_MESSAGE_ID: Literal[122919]
    FSYS_ROOT_DELETE: Literal[122920]
    FILE_EXISTS: Literal[122921]
    FILE_NOT_EXISTS: Literal[122922]
    FSYS_MISPLACED_CHAR: Literal[122923]
    FSYS_INVALID_CHAR: Literal[122924]
    FSYS_INVALID_DEVICE: Literal[122925]
    FSYS_ACCESS_DENIED: Literal[122926]
    FSYS_LOCK_VIOLATION: Literal[122927]
    FSYS_VOLUME_FULL: Literal[122928]
    FSYS_NOT_SUPPORTED: Literal[122929]
    FSYS_UNKNOWN: Literal[122930]
    FSYS_NOT_A_FILE: Literal[122931]
    FSYS_NOT_A_DIRECTORY: Literal[122932]
    FSYS_IS_WILDCARD: Literal[122933]
    RENAMED_WRONG_FILE_FORMAT: Literal[122934]
    FSYS_UPDATE_NEEDED: Literal[122935]
    FSYS_CANT_RESOLVE_CONFLICT: Literal[122936]
    FSYS_CANT_ITERATE: Literal[122937]
    ONE_NOT_SEARCHABLE: Literal[122938]
    MULTIPLE_NOT_SEARCHABLE: Literal[122939]
    FSYS_CACHE_INCONSISTENT: Literal[122940]
    FSYS_READONLY: Literal[122941]
    FSYS_LOCK: Literal[122942]
    FSYS_UNLOCK: Literal[122943]
    FSYS_DELETE: Literal[122944]
    FSYS_IS_MARKED: Literal[122945]
    FTP_GENERAL_FAILURE: Literal[122946]
    DO_LOG: Literal[122947]
    HTTP_COOKIE_REQUEST: Literal[122948]
    FSYS_LOST_ROOT: Literal[122949]
    FTP_PROXY: Literal[122950]
    SOURCE_SAME_AS_TARGET: Literal[122951]
    CONFIRM_EMPTY_TRASH: Literal[122952]
    FSYS_NO_TARGET: Literal[122953]
    FSYS_RECURSIVE: Literal[122954]
    FSYS_INSERT_MEDIUM: Literal[122955]
    NO_DOCINFO: Literal[122956]
    CCMAIL_EXPORT_NOT_TERMINATING: Literal[122957]
    EXTERNAL_COMMAND_FAILED: Literal[122958]
    RENAME_FAILED: Literal[122959]
    NOT_HANDLED: Literal[122960]
    COULD_NOT_INIT_COMPONENT: Literal[122961]
    TRANSFER_URL_NOT_SUPPORTED: Literal[122962]
    EMPTY_SERVERNAME: Literal[122963]
    EMPTY_USERNAME: Literal[122964]
    BAD_INET: Literal[122965]
    IMAP_SERVER_MSG: Literal[122966]
    IMAP_CONNECTION_CLOSED: Literal[122967]
    IMAP_NOT_IMAP4: Literal[122968]
    IMAP_BAD_SERVER: Literal[122969]
    REORGANIZE_FILE_LOCKED: Literal[122970]
    IMAP_BAD_TITLE: Literal[122971]
    SERVER_CONNECT_FAILURE: Literal[122972]
    PASSWORD_SYNTAX: Literal[122973]
    QUERY_DELETE_CACHE: Literal[122974]
    REORGANIZE_NO_DISKSPACE: Literal[122975]
    LOGIN_FAILURE_ACCOUNT: Literal[122976]
    ACCOUNT_SYNTAX: Literal[122977]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
from typing_extensions import Literal
"""
Const

These constants are used to specify the filter operator which should be applied when creating a filter with the method XSingleSelectQueryComposer.setStructuredFilter().

See Also:
    `API SQLFilterOperator <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1SQLFilterOperator.html>`_
"""
EQUAL: Literal[1]
"""
equal to
"""
NOT_EQUAL: Literal[2]
"""
not equal to
"""
LESS: Literal[3]
"""
less than
"""
GREATER: Literal[4]
"""
greater than
"""
LESS_EQUAL: Literal[5]
"""
less or equal than
"""
GREATER_EQUAL: Literal[6]
"""
greater or equal than
"""
LIKE: Literal[7]
"""
like
"""
NOT_LIKE: Literal[8]
"""
not like
"""
SQLNULL: Literal[9]
"""
is null
"""
NOT_SQLNULL: Literal[10]
"""
is not null
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_dispatch_provider_interceptor import XDispatchProviderInterceptor as XDispatchProviderInterceptor_afda1275

class XDispatchProviderInterception(XInterface_8f010a43):
    """
    makes it possible to register an XDispatchProvider which intercepts all requests of XDispatch to this instance.
    
    Note: Nobody can guarantee order of used interceptor objects if more than ones exist. Later registered ones will be used at first. But it's possible to increase the chance for that by providing the optional interface XInterceptorInfo.

    See Also:
        `API XDispatchProviderInterception <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDispatchProviderInterception.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XDispatchProviderInterception']

    def registerDispatchProviderInterceptor(self, Interceptor: 'XDispatchProviderInterceptor_afda1275') -> None:
        """
        registers an XDispatchProviderInterceptor, which will become the first interceptor in the chain of registered interceptors.
        """
    def releaseDispatchProviderInterceptor(self, Interceptor: 'XDispatchProviderInterceptor_afda1275') -> None:
        """
        removes an XDispatchProviderInterceptor which was previously registered
        
        The order of removals is arbitrary. It is not necessary to remove the last registered interceptor first.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47

class ModuleWindowStateConfiguration(XNameContainer_cb90e47):
    """
    Service Class

    a service which provides window based information about user interface elements of a single application module.
    
    Every OpenOffice.org module has an amount of user interface elements that can be positioned, resized, closed and their style can be changed. This service provides access to the window based information of available user interface elements which are part of a single OpenOffice.org module, like Writer or Calc.
    
    **since**
    
        OOo 2.0

    See Also:
        `API ModuleWindowStateConfiguration <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1ModuleWindowStateConfiguration.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4

class XBlob(XInterface_8f010a43):
    """
    is the representation (mapping) of an SQL BLOB.
    
    A SQL  BLOB  is a built-in type that stores a Binary Large Object as a column value in a row of a database table. The driver implements  BLOB  using a SQL locator(BLOB) , which means that a Blob object contains a logical pointer to the SQL  BLOB  data rather than the data itself.
    A Blob object is valid for the duration of the transaction in which is was created.
    
    Methods in the interfaces com.sun.star.sdbc.XResultSet , and com.sun.star.sdbc.XPreparedStatement , such as getBlob and setBlob allow a programmer to access the SQL BLOB.
    The Blob interface provides methods for getting the length of a SQL  BLOB  (Binary Large Object) value, for materializing a  BLOB  value on the client and for determining the position of a pattern of bytes within a  BLOB  value.

    See Also:
        `API XBlob <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBlob.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbc.XBlob']

    def getBinaryStream(self) -> 'XInputStream_98d40ab4':
        """
        retrieves the  BLOB  designated by this Blob instance as a stream.

        Raises:
            SQLException: ``SQLException``
        """
    def getBytes(self, pos: int, length: int) -> 'typing.Tuple[int, ...]':
        """
        returns as an array of bytes part or all of the  BLOB  value that this Blob object designates.
        
        The byte array contains up to length consecutive bytes starting at position pos.

        Raises:
            SQLException: ``SQLException``
        """
    def length(self) -> int:
        """
        returns the number of bytes in the  BLOB  value designated by this Blob object.

        Raises:
            SQLException: ``SQLException``
        """
    def position(self, pattern: 'typing.Tuple[int, ...]', start: int) -> int:
        """
        determines the byte position at which the specified byte pattern begins within the  BLOB  value that this Blob object represents.
        
        The search for pattern begins at position start.

        Raises:
            SQLException: ``SQLException``
        """
    def positionOfBlob(self, pattern: 'XBlob', start: int) -> int:
        """
        determines the byte position in the  BLOB  value designated by this Blob object at which pattern begins.
        
        The search begins at position start.

        Raises:
            SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.configuration
from .access_root_element import AccessRootElement as AccessRootElement_7fef1140
from .group_access import GroupAccess as GroupAccess_1f8f0edf
from .group_element import GroupElement as GroupElement_2f2a0f57
from .set_access import SetAccess as SetAccess_1ae0dfe
from .set_element import SetElement as SetElement_10680e76

class ConfigurationAccess(AccessRootElement_7fef1140, GroupAccess_1f8f0edf, GroupElement_2f2a0f57, SetAccess_1ae0dfe, SetElement_10680e76):
    """
    Service Class

    provides read access to a fragment of the configuration hierarchy.
    
    Values that are direct or indirect descendants of a root element can be retrieved and, if themselves objects, navigated. Other interfaces provide access to information about this element and its context. Changes to values in the hierarchy can be monitored by event listeners.
    
    Descendants of this service also implement this service.
    
    Ultimately the configuration holds values. These values are organized into a hierarchy using structural elements. The structure is defined in advance in a schema. Necessary information from the schema is stored in the configuration repository itself and is accessible through an implementation of this service.
    
    Two different kinds of structural elements are used in the configuration hierarchy:
    
    Objects in the configuration hierarchy, for example, implementations of this service, can thus be classified in the following ways:
    
    Several types of simple values can be used in the configuration. In addition to the basic (scalar) types, sequences of the basic types are supported. The basic types are:
    
    Within templates an additional type any can occur. When such a template is used to create a new SetElement, the type of the element is initially reported as any (having no value). When the value of such an element is first set, it will assume the type used.
    
    If the schema marks a value as nullable (which is indicated by attribute com.sun.star.beans.PropertyAttribute.MAYBEVOID ), its contents may be NULL.
    
    The configuration should support explicit access to default values (implementing com.sun.star.beans.XPropertyState and com.sun.star.beans.XPropertyWithState).

    See Also:
        `API ConfigurationAccess <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1ConfigurationAccess.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.accessibility
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class AccessibleTableModelChange(object):
    """
    Struct Class

    This structure lets an event give access to a change of a table model.
    
    The data members of the AccessibleTableModelChange structure give access to the type and cell range of a change of a table model. See AccessibleTableModelChangeType for details of the change type. The range of the affected rows, columns, and/or cells can be obtained by accessing the other four data members.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleTableModelChange <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1accessibility_1_1AccessibleTableModelChange.html>`_
    """
    typeName: Literal['com.sun.star.accessibility.AccessibleTableModelChange']

    def __init__(self, Type: typing.Optional[int] = ..., FirstRow: typing.Optional[int] = ..., LastRow: typing.Optional[int] = ..., FirstColumn: typing.Optional[int] = ..., LastColumn: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Type (int, optional): Type value.
            FirstRow (int, optional): FirstRow value.
            LastRow (int, optional): LastRow value.
            FirstColumn (int, optional): FirstColumn value.
            LastColumn (int, optional): LastColumn value.
        """


    @property
    def Type(self) -> int:
        """
        The type of the event as defined in AccessibleTableModelChangeType.
        
        The model change either inserted or deleted one or more rows and/or columns or modified the content of a number of cells. See AccessibleTableModelChangeType for details of the type of the model change.
        """


    @property
    def FirstRow(self) -> int:
        """
        The lowest index of a row that has changed.
        
        The first row that has been changed or that contains modified cells.
        """


    @property
    def LastRow(self) -> int:
        """
        The highest index of a row that has changed.
        
        The last row that has been changed or that contains modified cells.
        """


    @property
    def FirstColumn(self) -> int:
        """
        The lowest index of a column that has changed.
        
        The first column that has been changed or contains modified cells.
        """


    @property
    def LastColumn(self) -> int:
        """
        The highest index of a column that has changed.
        
        The last column that has been changed or contains modified cells.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.3
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from ..util.url import URL as URL_57ad07b9


class FeatureStateEvent(EventObject_a3d70b03):
    """
    Struct Class

    This event is broadcast by a Controller whenever the state of the feature changes.

    See Also:
        `API FeatureStateEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1FeatureStateEvent.html>`_
    """
    typeName: Literal['com.sun.star.frame.FeatureStateEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., FeatureURL: typing.Optional[URL_57ad07b9] = ..., FeatureDescriptor: typing.Optional[str] = ..., IsEnabled: typing.Optional[bool] = ..., Requery: typing.Optional[bool] = ..., State: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            FeatureURL (URL, optional): FeatureURL value.
            FeatureDescriptor (str, optional): FeatureDescriptor value.
            IsEnabled (bool, optional): IsEnabled value.
            Requery (bool, optional): Requery value.
            State (object, optional): State value.
        """


    @property
    def FeatureURL(self) -> URL_57ad07b9:
        """
        contains the URL of the feature.
        """


    @property
    def FeatureDescriptor(self) -> str:
        """
        contains a descriptor of the feature for the user interface.
        """


    @property
    def IsEnabled(self) -> bool:
        """
        specifies whether the feature is currently enabled or disabled.
        """


    @property
    def Requery(self) -> bool:
        """
        specifies whether the XDispatch has to be required.
        
        Interest code should listen for FrameActionEvent too, to update own feature states and dispatch listener on FrameAction.CONTEXT_CHANGED.
        """


    @property
    def State(self) -> object:
        """
        contains the state of the feature in this dispatch.
        
        This can be, for example, simply TRUE for a boolean feature like underline on/off. Some simple types like string or boolean are useful here for generic UI elements, like a checkmark in a menu.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.validation
from ..binding.bindable_control_model import BindableControlModel as BindableControlModel_9a1111a8
from .validatable_control_model import ValidatableControlModel as ValidatableControlModel_12621440

class ValidatableBindableControlModel(BindableControlModel_9a1111a8, ValidatableControlModel_12621440):
    """
    Service Class

    specifies a control model which supports both binding to an external value supplier, and to an external validator.
    
    There are two methods how the value which is represented by a control model can interact with other components (well, except the trivial ones accessible by using com.sun.star.beans.XPropertySet):
    
    The ValidatableBindableControlModel services describes the interaction of these concepts for control models which support both of them.

    See Also:
        `API ValidatableBindableControlModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1validation_1_1ValidatableBindableControlModel.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.loader.cannot_activate_factory_exception import CannotActivateFactoryException as CannotActivateFactoryException
from .._pyi.loader.dynamic import Dynamic as Dynamic
from .._pyi.loader.java import Java as Java
from .._pyi.loader.java2 import Java2 as Java2
from .._pyi.loader.shared_library import SharedLibrary as SharedLibrary
from .._pyi.loader.x_implementation_loader import XImplementationLoader as XImplementationLoader



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class Pair(object):
    """
    Struct Class

    A tuple, or pair.
    
    This structure allows for conveniently packing together two values of any type, and could be useful as the result type of methods.
    
    **since**
    
        OOo 3.0

    See Also:
        `API Pair <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1Pair_3_01T_00_01U_01_4.html>`_
    """
    typeName: Literal['com.sun.star.beans.Pair']

    def __init__(self, First: typing.Optional[object] = ..., Second: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            First (object, optional): First value.
            Second (object, optional): Second value.
        """


    @property
    def First(self) -> object:
        """
        first object.
        """


    @property
    def Second(self) -> object:
        """
        second object.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script
# Libre Office Version: 7.3
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .finish_reason import FinishReason as FinishReason_ca230c66


class FinishEngineEvent(EventObject_a3d70b03):
    """
    Struct Class

    event contains the reasons and the data for the XEngineListener.finished() method.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API FinishEngineEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1script_1_1FinishEngineEvent.html>`_
    """
    typeName: Literal['com.sun.star.script.FinishEngineEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., Finish: typing.Optional[FinishReason_ca230c66] = ..., ErrorMessage: typing.Optional[str] = ..., Return: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Finish (FinishReason, optional): Finish value.
            ErrorMessage (str, optional): ErrorMessage value.
            Return (object, optional): Return value.
        """


    @property
    def Finish(self) -> FinishReason_ca230c66:
        """
        specifies why the script terminates.
        """


    @property
    def ErrorMessage(self) -> str:
        """
        error message.
        
        Only valid if Reason is RuntimeError or CompileError.
        """


    @property
    def Return(self) -> object:
        """
        contains the return value.
        
        This field is only valid if FinishEngineEvent.Finish is FinishReason.OK.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.geometry
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class IntegerBezierSegment2D(object):
    """
    Struct Class

    This structure contains the relevant data for a cubic Bezier curve.
    
    The data is stored integer-valued. The last point of the segment is taken from the first point of the following segment, and thus not included herein. That is, when forming a polygon out of cubic Bezier segments, each two consecutive IntegerBezierSegment2Ds define the actual curve, with the very last segment providing only the end point of the last curve, and the remaining members ignored.
    
    **since**
    
        OOo 2.0

    See Also:
        `API IntegerBezierSegment2D <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1geometry_1_1IntegerBezierSegment2D.html>`_
    """
    typeName: Literal['com.sun.star.geometry.IntegerBezierSegment2D']

    def __init__(self, Px: typing.Optional[int] = ..., Py: typing.Optional[int] = ..., C1x: typing.Optional[int] = ..., C1y: typing.Optional[int] = ..., C2x: typing.Optional[int] = ..., C2y: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Px (int, optional): Px value.
            Py (int, optional): Py value.
            C1x (int, optional): C1x value.
            C1y (int, optional): C1y value.
            C2x (int, optional): C2x value.
            C2y (int, optional): C2y value.
        """


    @property
    def Px(self) -> int:
        """
        The x coordinate of the start point.
        """


    @property
    def Py(self) -> int:
        """
        The y coordinate of the start point.
        """


    @property
    def C1x(self) -> int:
        """
        The x coordinate of the first control point.
        """


    @property
    def C1y(self) -> int:
        """
        The y coordinate of the first control point.
        """


    @property
    def C2x(self) -> int:
        """
        The x coordinate of the second control point.
        """


    @property
    def C2y(self) -> int:
        """
        The y coordinate of the second control point.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
from ..linguistic2.x_hyphenator import XHyphenator as XHyphenator_ff4e0def


class LineBreakHyphenationOptions(object):
    """
    Struct Class

    Hyphenation options passed in calls to XBreakIterator.getLineBreak().

    See Also:
        `API LineBreakHyphenationOptions <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1LineBreakHyphenationOptions.html>`_
    """
    typeName: Literal['com.sun.star.i18n.LineBreakHyphenationOptions']

    def __init__(self, rHyphenator: typing.Optional[XHyphenator_ff4e0def] = ..., aHyphenationOptions: typing.Optional[PropertyValues_d6470ce6] = ..., hyphenIndex: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            rHyphenator (XHyphenator, optional): rHyphenator value.
            aHyphenationOptions (PropertyValues, optional): aHyphenationOptions value.
            hyphenIndex (int, optional): hyphenIndex value.
        """


    @property
    def rHyphenator(self) -> XHyphenator_ff4e0def:
        """
        Reference to the specific hyphenator - can be zero.
        """


    @property
    def aHyphenationOptions(self) -> PropertyValues_d6470ce6:
        """
        Sequence of property values to be used by the hyphenator - can be empty if the default values (from the property set) should be used.
        """


    @property
    def hyphenIndex(self) -> int:
        """
        The first character not fitting to the current line, considering an additional \"-\" for hyphenation.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.3
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .point import Point as Point_5fb2085e
from .rectangle import Rectangle as Rectangle_84b109e9


class DockingEvent(EventObject_a3d70b03):
    """
    Struct Class

    specifies a docking event.

    See Also:
        `API DockingEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1DockingEvent.html>`_
    """
    typeName: Literal['com.sun.star.awt.DockingEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., TrackingRectangle: typing.Optional[Rectangle_84b109e9] = ..., MousePos: typing.Optional[Point_5fb2085e] = ..., bLiveMode: typing.Optional[bool] = ..., bInteractive: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            TrackingRectangle (Rectangle, optional): TrackingRectangle value.
            MousePos (Point, optional): MousePos value.
            bLiveMode (bool, optional): bLiveMode value.
            bInteractive (bool, optional): bInteractive value.
        """


    @property
    def TrackingRectangle(self) -> Rectangle_84b109e9:
        """
        specifies the current tracking rectangle
        """


    @property
    def MousePos(self) -> Point_5fb2085e:
        """
        specifies the current mouse position in frame coordinates
        """


    @property
    def bLiveMode(self) -> bool:
        """
        specifies if the layout should be adjusted immediately
        """


    @property
    def bInteractive(self) -> bool:
        """
        specifies if the docking procedure is interactive which means that the user is currently dragging the window to a new position if this member is FALSE the window will be docked or undocked immediately using the returned tracking rectangle
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart
from .x_axis_z_supplier import XAxisZSupplier as XAxisZSupplier_d44c0cb5

class ChartAxisZSupplier(XAxisZSupplier_d44c0cb5):
    """
    Service Class

    A helper service for chart documents which supply a z-axis.

    See Also:
        `API ChartAxisZSupplier <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartAxisZSupplier.html>`_
    """
    @property
    def HasZAxis(self) -> bool:
        """
        Determines if the z-axis is shown or hidden.
        """
    @property
    def HasZAxisDescription(self) -> bool:
        """
        Determines if the description of the z-axis is shown or hidden.
        """
    @property
    def HasZAxisGrid(self) -> bool:
        """
        Determines if the major grid of the z-axis is shown or hidden.
        """
    @property
    def HasZAxisHelpGrid(self) -> bool:
        """
        Determines if the minor grid of the z-axis is shown or hidden.
        """
    @property
    def HasZAxisTitle(self) -> bool:
        """
        Determines if the title of the z-axis is shown or hidden.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class NumberFormatCode(object):
    """
    Struct Class

    Number format code information returned by various XNumberFormatCode methods.

    See Also:
        `API NumberFormatCode <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1NumberFormatCode.html>`_
    """
    typeName: Literal['com.sun.star.i18n.NumberFormatCode']

    def __init__(self, Type: typing.Optional[int] = ..., Usage: typing.Optional[int] = ..., Code: typing.Optional[str] = ..., DefaultName: typing.Optional[str] = ..., NameID: typing.Optional[str] = ..., Index: typing.Optional[int] = ..., Default: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Type (int, optional): Type value.
            Usage (int, optional): Usage value.
            Code (str, optional): Code value.
            DefaultName (str, optional): DefaultName value.
            NameID (str, optional): NameID value.
            Index (int, optional): Index value.
            Default (bool, optional): Default value.
        """


    @property
    def Type(self) -> int:
        """
        One of KNumberFormatType values.
        """


    @property
    def Usage(self) -> int:
        """
        One of KNumberFormatUsage values.
        """


    @property
    def Code(self) -> str:
        """
        Format code, for example, \"YYYY-MM-DD\".
        """


    @property
    def DefaultName(self) -> str:
        """
        Descriptive name of the format for this locale.
        """


    @property
    def NameID(self) -> str:
        """
        Message identifier to be used if the name of the format is localized.
        """


    @property
    def Index(self) -> int:
        """
        Index of the code as defined in NumberFormatIndex.
        """


    @property
    def Default(self) -> bool:
        """
        If this format is the default format of the Usage group.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
    from ..lang.locale import Locale as Locale_70d308fa

class XDefaultNumberingProvider(XInterface_8f010a43):
    """
    provides access to default com.sun.star.text.NumberingRules according to a given locale information.

    See Also:
        `API XDefaultNumberingProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XDefaultNumberingProvider.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XDefaultNumberingProvider']

    def getDefaultContinuousNumberingLevels(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[PropertyValues_d6470ce6, ...]':
        """
        provides access to outline numberings according to a given com.sun.star.lang.Locale.
        
        In contrast to outline numberings the continuous numberings consist of level using the equal settings in all numbering levels.
        """
    def getDefaultOutlineNumberings(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[XIndexAccess_f0910d6d, ...]':
        """
        provides access to outline numberings according to a given com.sun.star.lang.Locale.
        
        Outline numberings usually consist of levels with different settings.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.report
from typing_extensions import Literal
import typing
from ..container.x_child import XChild as XChild_a6390b07
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .x_group import XGroup as XGroup_86540a09
    from .x_report_definition import XReportDefinition as XReportDefinition_ec30e81

class XGroups(XChild_a6390b07, XContainer_d6fb0cc6, XIndexContainer_1c040ebe, XComponent_98dc0ab5):
    """
    This interface specifies the groups collections of the report definition.

    See Also:
        `API XGroups <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XGroups.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.report.XGroups']

    def createGroup(self) -> 'XGroup_86540a09':
        """
        factory method for XGroup.
        """
    @property
    def ReportDefinition(self) -> 'XReportDefinition_ec30e81':
        """
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from .macro_expander import MacroExpander as MacroExpander_bca00bef

class BootstrapMacroExpander(MacroExpander_bca00bef, XInitialization_d46c0cca):
    """
    Service Class

    Macro expander expanding using rtl bootstrap notation.
    
    For details, have a look at http://udk.openoffice.org/common/man/concept/micro_deployment.html#misc
    
    The service can be instantiated via arguments giving an ini/rc file url. Otherwise it will read from a uno.ini/unorc file next to the cppuhelper library.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API BootstrapMacroExpander <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1util_1_1BootstrapMacroExpander.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
import typing
from .x_sprite import XSprite as XSprite_b2470b95
if typing.TYPE_CHECKING:
    from .x_canvas import XCanvas as XCanvas_b19b0b7a

class XCustomSprite(XSprite_b2470b95):
    """
    Interface to control a custom sprite object on a XSpriteCanvas.
    
    Every change performed on XCustomSprite objects is only visible after a XSpriteCanvas.updateScreen() call, to facilitate synchronized screen updates.
    
    TODO: Maybe more than alpha has to be overridden from render state. TODO: Provide means to change the output area

    See Also:
        `API XCustomSprite <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XCustomSprite.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rendering.XCustomSprite']

    def getContentCanvas(self) -> 'XCanvas_b19b0b7a':
        """
        Query a render canvas for this sprite's content.
        
        Whatever is rendered to this canvas will become visible on the screen only after a XSpriteCanvas.updateScreen() call at the associated sprite canvas. This canvas is not equivalent to the host canvas of the sprite. At the very least, all output happens relative to the sprite's upper left corner, i.e. the origin of the sprite's canvas device coordinate system will move with the sprite across the screen.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.embed
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .wrong_state_exception import WrongStateException as WrongStateException_19f60ec2
from ..uno.x_interface import XInterface as XInterface_8f010a43

class NeedsRunningStateException(WrongStateException_19f60ec2):
    """
    Exception Class

    This exception can be thrown in case a list of accepted verbs of states is requested and the object is in loaded state and this information can be retrieved only when the object is in running state.
    
    This exception means that the object supports at least running state in addition to the loaded state. Other states and possible verbs can be detected only after object is switched to running state.

    See Also:
        `API NeedsRunningStateException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1embed_1_1NeedsRunningStateException.html>`_
    """

    typeName: Literal['com.sun.star.embed.NeedsRunningStateException']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
        """

__all__ = ['NeedsRunningStateException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering
from typing_extensions import Literal


class ColorComponentTag(object):
    """
    Const

    A collection of tags for the individual components of a color.
    
    Color components usually correspond to physical attributes like the amount of red colorant contained in an output color. This constant field enumerates the most common ones.
    
    **since**
    
        OOo 2.3

    See Also:
        `API ColorComponentTag <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1ColorComponentTag.html>`_
    """
    DEVICE: Literal[0]
    """
    Unspecified device color value.
    """
    RGB_RED: Literal[1]
    """
    Red colorant from RGB color space.
    """
    RGB_GREEN: Literal[2]
    """
    Green colorant from RGB color space.
    """
    RGB_BLUE: Literal[3]
    """
    Blue colorant from RGB color space.
    """
    CMYK_CYAN: Literal[4]
    """
    Cyan colorant from CMYK color space.
    """
    CMYK_MAGENTA: Literal[5]
    """
    Magenta colorant from CMYK color space.
    """
    CMYK_YELLOW: Literal[6]
    """
    Yellow colorant from CMYK color space.
    """
    CMYK_BLACK: Literal[7]
    """
    Black colorant from CMYK color space.
    """
    CMYKOG_ORANGE: Literal[8]
    """
    Orange colorant from hexachrome color space.
    """
    CMYKOG_GREEN: Literal[9]
    """
    Green colorant from hexachrome color space.
    """
    SPOT: Literal[10]
    """
    Arbitrary extra spot color, e.g. Pantone.
    """
    INDEX: Literal[11]
    """
    Index into palette.
    """
    ALPHA: Literal[12]
    """
    Alpha channel.
    """
    GREY: Literal[13]
    """
    Grey value. Used for monochrome color spaces.
    """
    PREMULTIPLIED_ALPHA: Literal[14]
    """
    Premultiplied alpha channel.
    
    Note that this alpha format actually influences the other color components, in that their values are pre-multiplied with the alpha value.
    """
    CIEXYZ_X: Literal[15]
    """
    CieXYZ X value.
    """
    CIEXYZ_Y: Literal[16]
    """
    CieXYZ Y value.
    """
    CIEXYZ_Z: Literal[17]
    """
    CieXYZ Z value.
    """
    CIELAB_L: Literal[18]
    """
    CieLab L value.
    """
    CIELAB_A: Literal[19]
    """
    CieLab a value.
    """
    CIELAB_B: Literal[20]
    """
    CieLab b value.
    """
    HSV_H: Literal[21]
    """
    HSV H value.
    """
    HSV_S: Literal[22]
    """
    HSV S value.
    """
    HSV_V: Literal[23]
    """
    HSV V value.
    """
    HSL_H: Literal[24]
    """
    HSL H value.
    """
    HSL_S: Literal[25]
    """
    HSL S value.
    """
    HSL_L: Literal[26]
    """
    HSL L value.
    """
    YCBCR_Y: Literal[27]
    """
    YCbCr Y value.
    """
    YCBCR_CB: Literal[28]
    """
    YCbCr Cb value.
    """
    YCBCR_CR: Literal[29]
    """
    YCbCr Cr value.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XAccessibleImage(XInterface_8f010a43):
    """
    Implement this interface to represent images and icons.
    
    This interface is used for a representation of images like icons of buttons. The corresponding interface of the Java Accessibility API is AccessibleIcon. This interface lets you retrieve an image's size and description.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleImage <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleImage.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleImage']

    def getAccessibleImageDescription(self) -> str:
        """
        Returns the localized description of the image.
        
        It depends on the usage of an image whether the description should express the image's function (e.g. for icons) or the actual content of the image (e.g. for image maps or non-iconic images embedded into a document.)
        """
    def getAccessibleImageHeight(self) -> int:
        """
        Returns the height of the image.
        
        The height is returned in units specified by the parents coordinate system.
        """
    def getAccessibleImageWidth(self) -> int:
        """
        Returns the width of the image.
        
        The width is returned in units specified by the parents coordinate system.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .general_function import GeneralFunction as GeneralFunction_e2280d25
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XConsolidationDescriptor(XInterface_8f010a43):
    """
    provides access to the settings of a consolidation descriptor.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XConsolidationDescriptor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XConsolidationDescriptor.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XConsolidationDescriptor']

    def getFunction(self) -> 'GeneralFunction_e2280d25':
        """
        returns the function by which the ranges are consolidated.
        """
    def getInsertLinks(self) -> bool:
        """
        returns, whether links to the original data are inserted in the output area or not.
        """
    def getSources(self) -> 'typing.Tuple[CellRangeAddress_ec450d43, ...]':
        """
        returns the cell ranges which are consolidated.
        """
    def getStartOutputPosition(self) -> 'CellAddress_ae5f0b56':
        """
        returns the position of the top left cell of the cell range where the consolidated data are copied.
        """
    def getUseColumnHeaders(self) -> bool:
        """
        returns, whether column headers from the cell ranges are used to find matching data or not.
        """
    def getUseRowHeaders(self) -> bool:
        """
        returns, whether row headers from the cell ranges are used to find matching data or not.
        """
    def setFunction(self, nFunction: 'GeneralFunction_e2280d25') -> None:
        """
        sets the function by which the ranges are consolidated.
        """
    def setInsertLinks(self, bInsertLinks: bool) -> None:
        """
        specifies if links to the original data are inserted in the output area.
        """
    def setSources(self, aSources: 'typing.Tuple[CellRangeAddress_ec450d43, ...]') -> None:
        """
        sets the cell ranges which are consolidated.
        """
    def setStartOutputPosition(self, aStartOutputPosition: 'CellAddress_ae5f0b56') -> None:
        """
        sets the position of the top left cell of the cell range where the consolidated data are copied.
        """
    def setUseColumnHeaders(self, bUseColumnHeaders: bool) -> None:
        """
        specifies if column headers from the cell ranges are used to find matching data.
        """
    def setUseRowHeaders(self, bUseRowHeaders: bool) -> None:
        """
        specifies if row headers from the cell ranges are used to find matching data.
        """

